.. vim: set fileencoding=utf-8 :

.. Place here references to all citations in lower case
.. _rudderstack: https://rudderstack.com
.. _python: http://www.python.org
.. _pypi: http://pypi.python.org
.. _setuptools: https://setuptools.readthedocs.io
.. _pre-commit: https://pre-commit.com/
